logo
Utility methods for running the auction in a test or bench context.

Constants

Initial balance for delegators in our test.

Amount of time to step foward between runs of the auction in our tests.

Functions

Creates a delegation request.

Generate key_count public keys.

Run a block with transfers and optionally run step.

Runs genesis, creates system, validator and delegator accounts, and funds the system account and delegator accounts.

Build a step request and run the auction.