logo
Utilities for running transfers in a test or bench context.

Constants

Test value for number of deploys to generate for a block.

Test target address.

Size of batch used in multiple execs benchmark, and multiple deploys per exec cases.

Functions

Creates a request that will call the create_accounts.wasm and create test accounts using the default account for the initial transfer.

Create initial accounts and run genesis.

Generate many native transfers from target_account.

Create a number of test purses with an initial balance.

Executes multiple deploys per single exec with based on TRANSFER_BATCH_SIZE.

Uses multiple exec requests with a single deploy to transfer tokens. Executes all transfers in batch determined by value of TRANSFER_BATCH_SIZE.

This test simulates flushing at the end of a block.

Executes multiple deploys per single exec with based on TRANSFER_BATCH_SIZE.

Uses multiple exec requests with a single deploy to transfer tokens from purse to purse. Executes all transfers in batch determined by value of TRANSFER_BATCH_SIZE.