Module casper_engine_test_support::utils
source · [−]Expand description
Utility types and functions for working with execution engine tests.
Functions
Returns an ExecConfig.
Returns a GenesisConfig.
Returns a RunGenesisRequest.
Returns Option<Account>.
Returns a String concatenated from all of the error messages from the ExecutionResult.
Returns a Vec<Gas> representing gas consts for an ExecutionResult.
Returns an error if the ExecutionResult has an error.
Returns the success result of the ExecutionResult.
Reads a given compiled contract file based on path